# CHANGELOG


## v0.5.1 (2026-02-18)

### Bug Fixes

- Update lockfile
  ([`7e025a2`](https://github.com/supersubscript/phenotastic/commit/7e025a2f9289fd13659d93b3410386a03cbf96bc))

### Chores

- Merge branch 'main' of https://github.com/supersubscript/phenotastic
  ([`6577011`](https://github.com/supersubscript/phenotastic/commit/6577011f676c3f9ce89ce1d8376d8383ab6a191e))


## v0.5.0 (2026-02-17)

### Bug Fixes

- Correct typing issue
  ([`26e8e87`](https://github.com/supersubscript/phenotastic/commit/26e8e8713677d49e724f843c57d0ca55867caafd))

### Build System

- Change from mypy to ty
  ([`c5c3bbe`](https://github.com/supersubscript/phenotastic/commit/c5c3bbe881884a0cff872610e27aed69c04b370f))

- **release**: Update version to 0.5.0
  ([`37860cc`](https://github.com/supersubscript/phenotastic/commit/37860ccd2c4c56ff9fd059a5c6e3663a7ded71f8))

Automatically generated by python-semantic-release

### Chores

- Merge branch 'main' of https://github.com/supersubscript/phenotastic
  ([`8c2f3d4`](https://github.com/supersubscript/phenotastic/commit/8c2f3d4c45de7e452fbe1762abaa6d1d38ea7ba8))

### Documentation

- Add citation section
  ([`ac78812`](https://github.com/supersubscript/phenotastic/commit/ac78812d8e9cf2909bce7af3743884fb70614051))

### Features

- Update parameter/variable names to be more descriptive
  ([`059a902`](https://github.com/supersubscript/phenotastic/commit/059a90296e88d83a479ee557198d32a893233b45))


## v0.4.1 (2026-02-17)

### Bug Fixes

- Update lock file
  ([`01a60db`](https://github.com/supersubscript/phenotastic/commit/01a60db44a8fde631ca3381d672788afa9b83c62))

### Build System

- **release**: Update version to 0.4.1
  ([`74266c1`](https://github.com/supersubscript/phenotastic/commit/74266c11ef690ca0ffd21585cb446e9158b70db5))

Automatically generated by python-semantic-release

### Chores

- Add py.typed file
  ([`c9dd4cc`](https://github.com/supersubscript/phenotastic/commit/c9dd4cc78b2d47c55f4d576f54e153096a7f228f))

- Merge branch 'main' of https://github.com/supersubscript/phenotastic
  ([`27c6515`](https://github.com/supersubscript/phenotastic/commit/27c6515097cc859eac4d6e0a552e7682035f21c4))

- Use local mypy
  ([`0c1960e`](https://github.com/supersubscript/phenotastic/commit/0c1960ee59af6019b16f655b03531c0f3e612fb3))


## v0.4.0 (2026-02-17)

### Bug Fixes

- Set up proper pypi publishing
  ([`b7181aa`](https://github.com/supersubscript/phenotastic/commit/b7181aa63392ccaf686e8316f65f169b107df2b0))

- Update lock file
  ([`3831883`](https://github.com/supersubscript/phenotastic/commit/3831883f081946ab51e17e6580cf15859604e3fd))

### Build System

- **release**: Update version to 0.4.0
  ([`66d5f77`](https://github.com/supersubscript/phenotastic/commit/66d5f77f63b6c93af28e4ed6358bab3168b60449))

Automatically generated by python-semantic-release

### Chores

- Merge branch 'main' of https://github.com/supersubscript/phenotastic
  ([`5ea6281`](https://github.com/supersubscript/phenotastic/commit/5ea62817067bba78f729d4efa63c9c0fae3d370d))


## v0.3.1 (2026-02-17)

### Bug Fixes

- Fix broken lock file
  ([`54a2cad`](https://github.com/supersubscript/phenotastic/commit/54a2cad5875a517e46bd127c0570662b0362da48))

### Build System

- **release**: Update version to 0.3.1
  ([`a8a60eb`](https://github.com/supersubscript/phenotastic/commit/a8a60eb926d105ed075b02621d130944a599060d))

Automatically generated by python-semantic-release

### Chores

- Merge branch 'main' of https://github.com/supersubscript/phenotastic
  ([`521f2d3`](https://github.com/supersubscript/phenotastic/commit/521f2d3cff936fc6263b53b27d0450c7eb109dc4))

### Features

- Refactor pipeline to use a simpler framework
  ([`aa9742f`](https://github.com/supersubscript/phenotastic/commit/aa9742fc0ca8df3890439481a2db5e48ae5787fb))


## v0.3.0 (2026-02-17)

### Bug Fixes

- Fix broken wrappign
  ([`190e5c5`](https://github.com/supersubscript/phenotastic/commit/190e5c52dbf067be673d0138739f467a460ae3d5))

### Build System

- **release**: Update version to 0.3.0
  ([`5e92b81`](https://github.com/supersubscript/phenotastic/commit/5e92b8198654693c704ed87fad96a7bec8543fb9))

Automatically generated by python-semantic-release

### Chores

- Merge branch 'main' of https://github.com/supersubscript/phenotastic
  ([`1cac2a5`](https://github.com/supersubscript/phenotastic/commit/1cac2a54ecc5085500bd396013bb5574c9e3de53))

### Features

- Make phenomeshes be polydata
  ([`99386c5`](https://github.com/supersubscript/phenotastic/commit/99386c5c49561dd5abe3cd758f1751e248f47782))


## v0.2.0 (2026-02-16)

### Build System

- **release**: Update version to 0.2.0
  ([`b847245`](https://github.com/supersubscript/phenotastic/commit/b8472455ffa7ea339f1a354944b62b200eafe7cf))

Automatically generated by python-semantic-release

### Features

- Add utils
  ([`206a212`](https://github.com/supersubscript/phenotastic/commit/206a21285cac96d637db88391b12eace90fcd8d9))

### Refactoring

- Simplify config interface
  ([`e035c2c`](https://github.com/supersubscript/phenotastic/commit/e035c2cddb9e87b5477e639fd339d792a058b18c))


## v0.1.1 (2026-02-16)

### Build System

- **release**: Update version to 0.1.1
  ([`878b483`](https://github.com/supersubscript/phenotastic/commit/878b483771ef34f9f50fd439ec646b91130a733b))

Automatically generated by python-semantic-release

### Chores

- Remove cursorrules
  ([`132f304`](https://github.com/supersubscript/phenotastic/commit/132f304bea179d6a91a7476e832c3bdf19a218ac))


## v0.1.0 (2026-02-16)

### Build System

- Remove unused deps
  ([`c631c2a`](https://github.com/supersubscript/phenotastic/commit/c631c2a4addd53cdccfa1d6b044e86d4f2167383))

- Update everything
  ([`6b93454`](https://github.com/supersubscript/phenotastic/commit/6b934542d2b396fbcf040ec8e5d39843c9d1a46a))

- **release**: Update version to 0.1.0
  ([`be492ea`](https://github.com/supersubscript/phenotastic/commit/be492eaa4132040dbb981b1fae03d338e165907a))

Automatically generated by python-semantic-release

### Chores

- Remove unused files
  ([`28e2fad`](https://github.com/supersubscript/phenotastic/commit/28e2fad53968e8d66af88d29ba4b7534a6b2979d))

- Update version control flags
  ([`bf66505`](https://github.com/supersubscript/phenotastic/commit/bf665059985d8ac76ff4e0ad8ba635bd6c19f4cd))

### Code Style

- Add type annotations
  ([`fe55b43`](https://github.com/supersubscript/phenotastic/commit/fe55b4333a90a95795569a7a18261accb1df07fe))

- Format
  ([`a31578f`](https://github.com/supersubscript/phenotastic/commit/a31578f838bd48e07069cedcd78cca8873e5031f))

### Features

- Add dockerfile
  ([`0690756`](https://github.com/supersubscript/phenotastic/commit/06907562153e290bcd074ec250ea832ec81fc981))

- Add makefile
  ([`caa45c3`](https://github.com/supersubscript/phenotastic/commit/caa45c393ce9746570773fd0f0bc66e1f93b8ffe))

- Add pipeline
  ([`41b57c9`](https://github.com/supersubscript/phenotastic/commit/41b57c90e304e5a57aed1d920f406909766c64ec))

- Slim down everything
  ([`056efd7`](https://github.com/supersubscript/phenotastic/commit/056efd724566674f9d0acb12386a3b3c5c3a9d60))

### Refactoring

- Improve names and simplify code
  ([`a9fc0f7`](https://github.com/supersubscript/phenotastic/commit/a9fc0f7a8b4dab6435f2e833d543c12454c51605))
